summaryrefslogtreecommitdiff
path: root/mpn/vax
diff options
context:
space:
mode:
Diffstat (limited to 'mpn/vax')
-rw-r--r--mpn/vax/add_n.s6
-rw-r--r--mpn/vax/addmul_1.s6
-rw-r--r--mpn/vax/lshift.s6
-rw-r--r--mpn/vax/mul_1.s6
-rw-r--r--mpn/vax/rshift.s6
-rw-r--r--mpn/vax/sub_n.s6
-rw-r--r--mpn/vax/submul_1.s6
7 files changed, 21 insertions, 21 deletions
diff --git a/mpn/vax/add_n.s b/mpn/vax/add_n.s
index e24e1b6fc..e640413bd 100644
--- a/mpn/vax/add_n.s
+++ b/mpn/vax/add_n.s
@@ -1,4 +1,4 @@
# VAX __mpn_add_n -- Add two limb vectors of the same length > 0 and store
# sum in a third limb vector.
# Copyright (C) 1999 Free Software Foundation, Inc.
@@ -29,8 +29,8 @@
.text
.align 1
-.globl ___mpn_add_n
-___mpn_add_n:
+.globl ___gmpn_add_n
+___gmpn_add_n:
.word 0x0
movl 16(ap),r0
movl 12(ap),r1
@@ -1,4 +1,4 @@
-# VAX __mpn_add_n -- Add two limb vectors of the same length > 0 and store
+# VAX __gmpn_add_n -- Add two limb vectors of the same length > 0 and store
# sum in a third limb vector.
# Copyright (C) 1999 Free Software Foundation, Inc.
diff --git a/mpn/vax/addmul_1.s b/mpn/vax/addmul_1.s
index 70cd0451c..38ff93d98 100644
--- a/mpn/vax/addmul_1.s
+++ b/mpn/vax/addmul_1.s
@@ -1,4 +1,4 @@
# VAX __mpn_addmul_1 -- Multiply a limb vector with a limb and add
# the result to a second limb vector.
# Copyright (C) 1992, 1994, 1996 Free Software Foundation, Inc.
@@ -29,8 +29,8 @@
.text
.align 1
-.globl ___mpn_addmul_1
-___mpn_addmul_1:
+.globl ___gmpn_addmul_1
+___gmpn_addmul_1:
.word 0xfc0
movl 12(ap),r4
movl 8(ap),r8
@@ -1,4 +1,4 @@
-# VAX __mpn_addmul_1 -- Multiply a limb vector with a limb and add
+# VAX __gmpn_addmul_1 -- Multiply a limb vector with a limb and add
# the result to a second limb vector.
# Copyright (C) 1992, 1994, 1996 Free Software Foundation, Inc.
diff --git a/mpn/vax/lshift.s b/mpn/vax/lshift.s
index 7b9942df9..b870fc7c1 100644
--- a/mpn/vax/lshift.s
+++ b/mpn/vax/lshift.s
@@ -1,4 +1,4 @@
# VAX __mpn_lshift -- left shift.
# Copyright (C) 1999 Free Software Foundation, Inc.
@@ -30,8 +30,8 @@
.text
.align 1
-.globl ___mpn_lshift
-___mpn_lshift:
+.globl ___gmpn_lshift
+___gmpn_lshift:
.word 0x1c0
movl 4(ap),r7
movl 8(ap),r6
@@ -1,4 +1,4 @@
-# VAX __mpn_lshift -- left shift.
+# VAX __gmpn_lshift -- left shift.
# Copyright (C) 1999 Free Software Foundation, Inc.
diff --git a/mpn/vax/mul_1.s b/mpn/vax/mul_1.s
index 5a9b65b6e..b018e98a0 100644
--- a/mpn/vax/mul_1.s
+++ b/mpn/vax/mul_1.s
@@ -1,4 +1,4 @@
# VAX __mpn_mul_1 -- Multiply a limb vector with a limb and store
# the result in a second limb vector.
# Copyright (C) 1992, 1994, 1996 Free Software Foundation, Inc.
@@ -29,8 +29,8 @@
.text
.align 1
-.globl ___mpn_mul_1
-___mpn_mul_1:
+.globl ___gmpn_mul_1
+___gmpn_mul_1:
.word 0xfc0
movl 12(ap),r4
movl 8(ap),r8
@@ -1,4 +1,4 @@
-# VAX __mpn_mul_1 -- Multiply a limb vector with a limb and store
+# VAX __gmpn_mul_1 -- Multiply a limb vector with a limb and store
# the result in a second limb vector.
# Copyright (C) 1992, 1994, 1996 Free Software Foundation, Inc.
diff --git a/mpn/vax/rshift.s b/mpn/vax/rshift.s
index bb8c4fb2d..f11d8044b 100644
--- a/mpn/vax/rshift.s
+++ b/mpn/vax/rshift.s
@@ -1,4 +1,4 @@
# VAX __mpn_rshift -- right shift.
# Copyright (C) 1999 Free Software Foundation, Inc.
@@ -30,8 +30,8 @@
.text
.align 1
-.globl ___mpn_rshift
-___mpn_rshift:
+.globl ___gmpn_rshift
+___gmpn_rshift:
.word 0x1c0
movl 4(ap),r7
movl 8(ap),r6
@@ -1,4 +1,4 @@
-# VAX __mpn_rshift -- right shift.
+# VAX __gmpn_rshift -- right shift.
# Copyright (C) 1999 Free Software Foundation, Inc.
diff --git a/mpn/vax/sub_n.s b/mpn/vax/sub_n.s
index ed68b0f16..7c486c679 100644
--- a/mpn/vax/sub_n.s
+++ b/mpn/vax/sub_n.s
@@ -1,4 +1,4 @@
# VAX __mpn_sub_n -- Subtract two limb vectors of the same length > 0 and store
# difference in a third limb vector.
# Copyright (C) 1999 Free Software Foundation, Inc.
@@ -29,8 +29,8 @@
.text
.align 1
-.globl ___mpn_sub_n
-___mpn_sub_n:
+.globl ___gmpn_sub_n
+___gmpn_sub_n:
.word 0x0
movl 16(ap),r0
movl 12(ap),r1
@@ -1,4 +1,4 @@
-# VAX __mpn_sub_n -- Subtract two limb vectors of the same length > 0 and store
+# VAX __gmpn_sub_n -- Subtract two limb vectors of the same length > 0 and store
# difference in a third limb vector.
# Copyright (C) 1999 Free Software Foundation, Inc.
diff --git a/mpn/vax/submul_1.s b/mpn/vax/submul_1.s
index fa39d11e4..765793517 100644
--- a/mpn/vax/submul_1.s
+++ b/mpn/vax/submul_1.s
@@ -1,4 +1,4 @@
# VAX __mpn_submul_1 -- Multiply a limb vector with a limb and subtract
# the result from a second limb vector.
# Copyright (C) 1992, 1994, 1996 Free Software Foundation, Inc.
@@ -29,8 +29,8 @@
.text
.align 1
-.globl ___mpn_submul_1
-___mpn_submul_1:
+.globl ___gmpn_submul_1
+___gmpn_submul_1:
.word 0xfc0
movl 12(ap),r4
movl 8(ap),r8
@@ -1,4 +1,4 @@
-# VAX __mpn_submul_1 -- Multiply a limb vector with a limb and subtract
+# VAX __gmpn_submul_1 -- Multiply a limb vector with a limb and subtract
# the result from a second limb vector.
# Copyright (C) 1992, 1994, 1996 Free Software Foundation, Inc.